/* GTK+ - accessibility implementations
 * Copyright (C) 2002, 2004  Anders Carlsson <andersca@gnu.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library. If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef __GTK_ICON_VIEW_ACCESSIBLE_PRIVATE_H__
#define __GTK_ICON_VIEW_ACCESSIBLE_PRIVATE_H__

#include <gtk/a11y/gtkiconviewaccessible.h>
#include <gtk/gtkiconview.h>

G_BEGIN_DECLS

void gtk_icon_view_accessible_adjustment_changed (GtkIconViewAccessible *self);

void gtk_icon_view_accessible_update_model (GtkIconViewAccessible *self,
                                            GtkTreeModel          *model);

G_END_DECLS

#endif /* __GTK_ICON_VIEW_ACCESSIBLE_PRIVATE_H__ */
